Struct beefy_primitives::Commitment [−][src]
pub struct Commitment<TBlockNumber, TPayload> {
pub payload: TPayload,
pub block_number: TBlockNumber,
pub validator_set_id: ValidatorSetId,
}Expand description
A commitment signed by GRANDPA validators as part of BEEFY protocol.
The commitment contains a payload extracted from the finalized block at height block_number. GRANDPA validators collect signatures on commitments and a stream of such signed commitments (see SignedCommitment) forms the BEEFY protocol.
Fields
payload: TPayloadThe payload being signed.
This should be some form of cumulative representation of the chain (think MMR root hash). The payload should also contain some details that allow the light client to verify next validator set. The protocol does not enforce any particular format of this data, nor how often it should be present in commitments, however the light client has to be provided with full validator set whenever it performs the transition (i.e. importing first block with validator_set_id incremented).
block_number: TBlockNumberFinalized block number this commitment is for.
GRANDPA validators agree on a block they create a commitment for and start collecting signatures. This process is called a round. There might be multiple rounds in progress (depending on the block choice rule), however since the payload is supposed to be cumulative, it is not required to import all commitments. BEEFY light client is expected to import at least one commitment per epoch, but is free to import as many as it requires.
validator_set_id: ValidatorSetIdBEEFY validator set supposed to sign this commitment.
Validator set is changing once per epoch. The Light Client must be provided by details
about the validator set whenever it’s importing first commitment with a new
validator_set_id. Validator set data MUST be verifiable, for instance using
payload information.