Struct beefy_primitives::witness::SignedCommitmentWitness [−][src]
pub struct SignedCommitmentWitness<TBlockNumber, TPayload, TMerkleRoot> {
pub commitment: Commitment<TBlockNumber, TPayload>,
pub signed_by: Vec<bool>,
pub signatures_merkle_root: TMerkleRoot,
}Expand description
A light form of SignedCommitment.
This is a light (“witness”) form of the signed commitment. Instead of containing full list of signatures, which might be heavy and expensive to verify, it only contains a bit vector of validators which signed the original SignedCommitment and a merkle root of all signatures.
This can be used by light clients for 2-phase interactive verification (for instance for Ethereum Mainnet), in a commit-reveal like scheme, where first we submit only the signed commitment witness and later on, the client picks only some signatures to verify at random.
Fields
commitment: Commitment<TBlockNumber, TPayload>The full content of the commitment.
signed_by: Vec<bool>The bit vector of validators who signed the commitment.
signatures_merkle_root: TMerkleRootA merkle root of signatures in the original signed commitment.
Implementations
impl<TBlockNumber, TPayload, TMerkleRoot> SignedCommitmentWitness<TBlockNumber, TPayload, TMerkleRoot>
impl<TBlockNumber, TPayload, TMerkleRoot> SignedCommitmentWitness<TBlockNumber, TPayload, TMerkleRoot>
Convert SignedCommitment into SignedCommitmentWitness.
This takes a SignedCommitment, which contains full signatures and converts it into a witness form, which does not contain full signatures, only a bit vector indicating which validators have signed the original SignedCommitment and a merkle root of all signatures.
Returns the full list of signatures along with the witness.